@@ -1,4 +1,5 @@
-from moto.core import BackendDict, BaseBackend
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.utilities.utils import PARTITION_NAMES
 
 
 class InstanceMetadataBackend(BaseBackend):
@@ -9,5 +10,5 @@ instance_metadata_backends = BackendDict(
     InstanceMetadataBackend,
     "instance_metadata",
     use_boto3_regions=False,
-    additional_regions=["global"],
+    additional_regions=PARTITION_NAMES,
 )
